==> ws-v3.70.5-src.tar.gz: ws-v3.70-5/include/WSCdialog.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSCDIALOG_H
#define WSCDIALOG_H

#include <WScom.h>
#include <WSCbaseDialog.h>

#define WSCdialog_VER 1000
class WSCindexForm;

class WSCdialog :public WSCbaseDialog{

  protected:
    WSCform*       _area1;
    short     _wbg_no;

    WSMFpropertyDef( WSNworkBackColor,  short,      _wbg_no );


  public:
    WSCdialog(WSCbase*,char*);
    virtual ~WSCdialog();
    virtual  long initialize();

    virtual void adjustForm();
    virtual void onGuiPolicyChange(long);

    WSMFguiClassDef(WSCdialog,WSCbaseDialog);
    WSMFversionDef(WSCdialog);
};
#endif //WSCDIALOG_H

==> ws-v3.93.2-src.tar.gz: ws-v3.93-2/include/WSCdialog.h <==
//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#ifndef WSCDIALOG_H
#define WSCDIALOG_H

#include <WScom.h>
#include <WSCbaseDialog.h>

#define WSCdialog_VER 1000
class WSCindexForm;

class WSCdialog :public WSCbaseDialog{

  protected:
    WSCform*       _area1;
    short     _wbg_no;

    WSMFpropertyDef( WSNworkBackColor,  short,      _wbg_no );


  public:
    WSDLEX32 WSCdialog(WSCbase*,char*);
    WSDLEX32 virtual ~WSCdialog();
    WSDLEX32 virtual  long initialize();

    WSDLEX32 virtual void adjustForm();
    WSDLEX32 virtual void onGuiPolicyChange(long);

    WSMFguiClassDef(WSCdialog,WSCbaseDialog);
    WSMFversionDef(WSCdialog);
};
#endif //WSCDIALOG_H
